@@ -195,10 +195,31 @@ class HeaderInline(admin.TabularInline):
 class ApiCallAdmin(admin.ModelAdmin):
     inlines = [HeaderInline]
 
+    def _get_extra_context(self, request, extra_context=None):
+        extra_context = dict() if extra_context is None else extra_context
+        if not request.user.is_superuser:
+            owner_codes = QRCode.objects.only('title').filter(department__in=request.user.departments.all(),
+                                                              mode=QRCode.REDIRECT_MODE_CHOICES.API_CALL).all()
+        else:
+            owner_codes = QRCode.objects.only('title').filter(mode=QRCode.REDIRECT_MODE_CHOICES.API_CALL).all()
+        extra_context['owner_codes'] = owner_codes
+        return extra_context
+
+    def change_view(self, request, object_id, form_url='', extra_context=None):
+        extra_context = self._get_extra_context(request, extra_context=extra_context)
+        return super(ApiCallAdmin, self).add_view(request, form_url=form_url, extra_context=extra_context)
+
+    def add_view(self, request, form_url='', extra_context=None):
+        extra_context = self._get_extra_context(request, extra_context=extra_context)
+        return super(ApiCallAdmin, self).add_view(request, form_url=form_url, extra_context=extra_context)
+
     def get_field_queryset(self, db, db_field, request):
-        if db_field.name == 'code':
+        if db_field.name == 'link_url':
             if not request.user.is_superuser:
-                return db_field.remote_field.model.objects.filter(department__in=request.user.departments.all())
+                return db_field.remote_field.model.objects.filter(code__department__in=request.user.departments.all(),
+                                                                  code__mode=QRCode.REDIRECT_MODE_CHOICES.API_CALL)
+            else:
+                return db_field.remote_field.model.objects.filter(code__mode=QRCode.REDIRECT_MODE_CHOICES.API_CALL)
         return super(ApiCallAdmin, self).get_field_queryset(db, db_field, request)
 
 
